#ifndef __PTTHREAD_H__
#define __PTTHREAD_H__

#include <string>
#include <boost/thread/thread.hpp>
#include <boost/bind.hpp>
#include <boost/function.hpp>


class PtThread
{
public:
	PtThread(const char * const threadName = "") :
		m_bStop(false),
		m_bRunning(false),
		m_threadName(threadName)
	{}
	
	virtual ~PtThread()
	{}
	
	bool Start()
	{
		m_bRunning 	= true;
		m_bStop = false;
		
		
		try
		{
			boost::function<void (void)> f = boost::bind(&PtThread::Run, this);
			boost::thread thrd(f);
			
			return true;
		}
		catch(boost::thread_resource_error & e)
		{
			m_bRunning = false;
			return false;
		}
	}
	
	void Stop(bool bWait = true)
	{
		m_bStop = true;
		if(bWait)
			WaitExit();
	}
	
	

	bool IsThreadExited() const
	{
		return !m_bRunning;
	}

        void WaitExit(void)
        {
	  while(!IsThreadExited())
	    {
	      boost::this_thread::sleep(boost::posix_time::seconds(1));
	    }
        }

	
protected:
	volatile bool 	m_bStop;

	std::string		m_threadName;

	void Run(void)
	{
		DoWork();
		m_bRunning = false;
	}

	virtual void DoWork(void) = 0;

private:
	volatile bool 	m_bRunning;
};


#endif
