

#ifndef __ISPTHREAD_H__
#define __ISPTHREAD_H__

#include <boost/thread/mutex.hpp>

#include "PtThread.h"
#include "utility.h"
#include "PtDebug.h"

class ISPThread : public PtThread
{
 public:
 ISPThread(int & idx, boost::mutex & idxLock, priority_queue<pair<double, pair<int, int> > > & q, boost::mutex & qLock, const vector<list<RawLink> > & graph, double theta)
    :m_idx(idx),
    m_idxLock(idxLock),
    m_q(q),
    m_qLock(qLock),
    m_graph(graph),
    m_theta(theta),
    m_finishedNode(0)
    {}


 protected:
  virtual void DoWork(void)
  {
    while(!m_bStop)
      {
	int idx;
	{
	  boost::lock_guard<boost::mutex> lock(m_idxLock);
	  idx = m_idx;
	  if(idx >= m_graph.size())
	    {
	      Pt_Info << "finished ... " << endl;
	      break;
	    }
	  else
	    {
	      ++m_idx;
	    }
	}

	// work on graph[idx];
	set<int> s;
	s.insert(idx);
	double influ = IPInflu(s, m_graph, m_theta);
	{
	  boost::lock_guard<boost::mutex> lock(m_qLock);
	  m_q.push(make_pair(influ, make_pair(idx, 0)));
	}
	++m_finishedNode;

      }
    Pt_Info << "total nodes finished by this thread : " << m_finishedNode << endl;
  }

 private:
  int & m_idx;
  boost::mutex & m_idxLock;
  priority_queue<pair<double, pair<int, int> > > & m_q;
  boost::mutex & m_qLock;
  const vector<list<RawLink> > & m_graph;
  double m_theta;
  int m_finishedNode;
};

#endif

