#include <boost/random.hpp>
#include <boost/random/mersenne_twister.hpp>
#include <boost/date_time/posix_time/posix_time.hpp>

#include <iostream>
#include <string>
#include <set>

#include "PtDebug.h"
#include "time.h"
#include "utility.h"
#include "PtThread.h"

using namespace boost;

int main(int argc, char ** argv)
{
  if(argc != 5)
    {
      cout << "Input:" << endl <<
	"1. graph path" << endl <<
	"2. K" << endl <<
	"3. theta" << endl <<
	"4. thread number" << endl;

      return -1;
    }

  ifstream is(argv[1]);

  if(!is)
    {
      Pt_Info << "open file error... " << argv[1] << endl;
      return -1;
    }

  vector<list<int> > g;
  ReadSnapGraph(g, is);

  vector<list<RawLink> > rawGraph;
  int K, threadN;
  double theta;


  K = atoi(argv[2]);
  theta = atof(argv[3]);
  threadN = atoi(argv[4]);

  ConvertToWCRawGraph(g, rawGraph);

  vector<list<int> >().swap(g);


  set<int> seed;


  for(int i = 0; i < argc; ++i)
    cout << argv[i] << " ";
  cout << endl;

  Pt_Info << "IPCelfKNodesMT() starting ..." << endl;
  boost::posix_time::ptime start = boost::posix_time::microsec_clock::local_time();

  IPCelfKNodesMT(rawGraph, theta, K, seed, threadN);

  boost::posix_time::ptime end = boost::posix_time::microsec_clock::local_time();
  Pt_Info << "IPCelfKNodesMT() ending ..." << endl;

  Pt_Info << "duration : " << to_simple_string(end - start) << endl;

  //  Pt_Info << "influence for IP : " << MultiMonteCarlo(20000, seed, rawGraph) << endl << "seed set:" << endl;
  for(set<int>::iterator itor = seed.begin();
      itor != seed.end();
      ++itor)
    {
      cout << *itor << " ";
    }
  cout << endl;

  Pt_Info << "Peak memory : " << GetPeakMem() << " MB" << endl;

}

