#include <boost/random.hpp>
#include <boost/random/mersenne_twister.hpp>
#include <boost/date_time/posix_time/posix_time.hpp>

#include <iostream>
#include <string>
#include <set>

#include "PtDebug.h"
#include "time.h"
#include "utility.h"
#include "PtThread.h"

using namespace boost;

int main(int argc, char ** argv)
{
  if(argc != 4)
    {
      cout << "Input:" << endl <<
	"1. graph path" << endl <<
	"2. K" << endl <<
	"3. theta" << endl;

      return -1;
    }

  ifstream is(argv[1]);

  if(!is)
    {
      Pt_Info << "open file error... " << argv[1] << endl;
      return -1;
    }

  vector<list<int> > g;
  ReadSnapGraph(g, is);

  vector<list<RawLink> > rawGraph;
  int K;
  double theta;


  K = atoi(argv[2]);
  theta = atof(argv[3]);

  ConvertToWCRawGraph(g, rawGraph);
  
  vector<list<int> >().swap(g);
  set<int> seed;


  for(int i = 0; i < argc; ++i)
    cout << argv[i] << " ";
  cout << endl;




  Pt_Info << "RatioWeightedCombIPCelfKNodes() starting ..." << endl;
  boost::posix_time::ptime start = boost::posix_time::microsec_clock::local_time();

  RatioWeightedCombIPCelfKNodes(rawGraph, theta, K, seed);

  boost::posix_time::ptime end = boost::posix_time::microsec_clock::local_time();
  Pt_Info << "RatioWeightedCombIPCelfKNodes() ending ..." << endl;

  Pt_Info << "duration : " << to_simple_string(end - start) << endl;


  Pt_Info << "influence for ratio combined IP : " << MultiMonteCarlo(20000, seed, rawGraph) << endl << "seed set:" << endl;
  for(set<int>::iterator itor = seed.begin();
      itor != seed.end();
      ++itor)
    {
      cout << *itor << " ";
    }
  cout << endl;
  Pt_Info << "Peak memory : " << GetPeakMem() << " MB" << endl;
}

